<template>
  <div>
    <el-dialog :visible.sync="dialogVisible" :title="title" :close-on-click-modal="false" :modal-append-to-body="false" v-if="dialogVisible" width="564px">
      <el-form size="mini" label-width="120px" ref="form">
        <el-form-item label="分类名称：">
          <el-input maxlength="6" v-model="content" show-word-limit placeholder="请输入不超过6个汉字长度的内容"></el-input>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer buttonPosition">
        <el-button size="mini" @click="submit" type="primary"  :loading="loading">确定</el-button>
        <el-button size="mini" @click="dialogVisible = false">取消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import integralProdApi from '@/api/member/integralProd'
export default {
  props: {
    title: {
      type: String,
      default: null
    },
    show: {
      type: Boolean,
      default: false
    }
  },
  data () {
    return {
      dialogVisible: false,
      content: null,
      loading: false
    }
  },
  watch: {
    /**
     * 监控外部显示变量变化
     * 传递到dialog组件
     */
    show: function (newShow, oldShow) {
      this.dialogVisible = newShow
    },
    /**
     * 监控内部显示属性变化
     * 传递到外部调用变量
     */
    dialogVisible: function (newDialogShow, oldDialogShow) {
      this.$emit('update:show', newDialogShow)
      if (!newDialogShow) {
        this.content = null
      }
    }
  },
  methods: {
    // 确定
    async submit () {
      if (!this.content) {
        this.$message({
          message: '请输入分类名称',
          type: 'warning'
        })
        return
      }
      try {
        this.loading = true
        const res = await integralProdApi.addCategory({ categoryName: this.content, pid: '0', delStatus: '1' })
        if (res.code === '0' && res.data) {
          this.loading = false
          this.$emit('hand-content', { categoryName: res.data.categoryName, id: res.data.id })
          this.dialogVisible = false
        } else {
          this.loading = false
        }
      } catch (error) {
        this.loading = false
      }
    }
  }
}
</script>

<style>

</style>
